@@ -22,17 +22,17 @@ model = TRUE, x = FALSE, ...)
     if (length(Y) < 1)
         stop("empty model")
     if (all(Y > 0))
-        stop("invalid dependent variable, no zero value")
+        stop("invalid indicator variable, no zero value")
     if (!isTRUE(all.equal(as.vector(Y), as.integer(round(Y +
         0.001)))))
-        stop("invalid dependent variable, non-integer values")
+        stop("invalid indicator variable, non-integer values")
     Y <- as.integer(round(Y + 0.001))
     if (any(Y < 0))
         stop("invalid dependent variable, negative counts")
     if (any(!(Y %in% c(0, 1))))
-        stop("invalid dependent variable, not in c(0, 1)")
+        stop("invalid indicator variable, not in c(0, 1)")
     if (length(Y) != NROW(X))
-        stop("invalid dependent variable, not a vector")
+        stop("invalid indicator variable, not a vector")
     ## need to have covariates (i.e. not only intercept)
     ## but that covariate can be factor/numeric etc.
     if (identical(as.character(ff[[2]]), "1"))
@@ -41,6 +41,10 @@ model = TRUE, x = FALSE, ...)
     ## fitting
     out1 <- rsf.fit(X=X, Y=Y, m=m, link = "log", B = B,
         inits=inits, method = method, control=control, ...)
+    out1$coefficients <- out1$coefficients[-1]
+    out1$std.error <- out1$std.error[-1]
+    out1$np <- out1$np - 1
+    out1$bootstrap <- out1$bootstrap[-1,,drop=FALSE]
 
     ## return value assembly
     out1$call <- match.call()
@@ -51,6 +55,7 @@ model = TRUE, x = FALSE, ...)
         model= if (model) mf else NULL,
         x= if (x) X else NULL)
     out <- c(out1, out2)
+    out$fitted.values <- exp(drop(X %*% c(0, out1$coefficients)))
     ## defining object class
     class(out) <- "rsf"
     out
